@@ -1,3 +1,25 @@
+# Copyright (c) 2017 Mimer Information Technology
+
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+#
+# See license for more details.
+
 import unittest
 import time
 import math
@@ -197,7 +219,7 @@ create table monkeyTable (c1 INTEGER,
         b = random.randint(-2**63, 2**63 - 1)
         c = random.randint(-2**15, 2**15 - 1)
         d = str(uuid.uuid4())
-        e = str(uuid.uuid4())
+        e = uuid.uuid4().bytes
         f = str(uuid.uuid4())
         g = random.randint(0,1)
         h = random.random()
@@ -260,7 +282,7 @@ create table monkeyTable (c1 INTEGER,
             b = random.randint(-2**63, 2**63 - 1)
             c = random.randint(-2**15, 2**15 - 1)
             d = str(uuid.uuid4())
-            e = str(uuid.uuid4())
+            e = uuid.uuid4().bytes
             f = str(uuid.uuid4())
             g = random.randint(0,1)
             h = random.random()
@@ -273,7 +295,7 @@ create table monkeyTable (c1 INTEGER,
         b = random.randint(-2**63, 2**63 - 1)
         c = random.randint(-2**15, 2**15 - 1)
         d = str(uuid.uuid4())
-        e = str(uuid.uuid4())
+        e = uuid.uuid4().bytes
         f = str(uuid.uuid4())
         g = random.randint(0,1)
         h = random.random()
